# Youtube Autonomous Image Module

@deprecated module. This module has been refactored and now we have 'yta_image_base', 'yta_image_advanced' and more modules coming to make them more modular. This is the last commit.

The Image module.

This project needs:
- to_fill_this